@@ -6,9 +6,7 @@
 #' @return a character string of the study title
 #' @export
 #' @examples
-#' \dontrun{
 #' get_study_title('MTBLS375')
-#' }
 
 get_study_title <- function(study_id)
 {
@@ -17,11 +15,9 @@ get_study_title <- function(study_id)
       paste0(getOption('BASE_URL'),
              '/studies/',
              study_id,
-             '/title'),
-      httr::add_headers(user_token = getOption('MTBLS_API_KEY'))
+             '/title')
     )
 
-
   study_title_parse <- study_title %>% httr::content('parsed')
 
   return(study_title_parse$title)
